/* Copyright (C) 2007-2021 Open Information Security Foundation
 *
 * You can copy, redistribute or modify this Program under the terms of
 * the GNU General Public License version 2 as published by the Free
 * Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * version 2 along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

/**
 * \file
 *
 *  \author Breno Silva <breno.silva@gmail.com>
 *  \author Victor Julien <victor@inliniac.net>
 */

#ifndef SURICATA_DETECT_ENGINE_THRESHOLD_H
#define SURICATA_DETECT_ENGINE_THRESHOLD_H

#include "detect.h"
#include "detect-threshold.h"

void ThresholdInit(void);
void ThresholdDestroy(void);

uint32_t ThresholdsExpire(const SCTime_t ts);

const DetectThresholdData *SigGetThresholdTypeIter(
        const Signature *, const SigMatchData **, int list);
int PacketAlertThreshold(const DetectEngineCtx *, DetectEngineThreadCtx *,
        const DetectThresholdData *, Packet *, const Signature *, PacketAlert *);

void ThresholdListFree(void *ptr);
void ThresholdCacheThreadFree(void);

void FlowThresholdVarFree(void *ptr);

#endif /* SURICATA_DETECT_ENGINE_THRESHOLD_H */
